==> ejc-techmanagement-impl-3.0.0-20230804.033909-16-sources.jar: com/ejianc/business/techmanagement/bean/NewTechConstructionPlanEntity.java <==
package com.ejianc.business.techmanagement.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 新技术应用施工方案实体
 * 
 * @author generator
 * 
 */
 @TableName("ejc_techmanagement_newtech_construction_plan")
public class NewTechConstructionPlanEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="create_user_name")
    private String createUserName; // 创建人名称
    @TableField(value="modify_user_name")
    private String modifyUserName; // 修改人名称
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="bill_name")
    private String billName; // 单据名称
    @TableField(value="content_overview")
    private String contentOverview; // 内容概述
    @TableField(value="validation_opinion")
    private String validationOpinion; // 项目部审定意见
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value = "bill_state")
    private Integer billState; //单据状态
    @TableField(value="commit_date")
    private Date commitDate; // 提交日期
    @TableField(value="commit_user_name")
    private String commitUserName; // 提交人名称
    @TableField(value="commit_user_code")
    private String commitUserCode; // 提交人账号
    @TableField(value="effective_date")
    private Date effectiveDate; // 生效日期

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public String getModifyUserName() {
        return modifyUserName;
    }

    public void setModifyUserName(String modifyUserName) {
        this.modifyUserName = modifyUserName;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public String getBillName() {
        return billName;
    }

    public void setBillName(String billName) {
        this.billName = billName;
    }
    public String getContentOverview() {
        return contentOverview;
    }

    public void setContentOverview(String contentOverview) {
        this.contentOverview = contentOverview;
    }
    public String getValidationOpinion() {
        return validationOpinion;
    }

    public void setValidationOpinion(String validationOpinion) {
        this.validationOpinion = validationOpinion;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Date getCommitDate() {
        return commitDate;
    }

    public void setCommitDate(Date commitDate) {
        this.commitDate = commitDate;
    }
    public String getCommitUserName() {
        return commitUserName;
    }

    public void setCommitUserName(String commitUserName) {
        this.commitUserName = commitUserName;
    }
    public String getCommitUserCode() {
        return commitUserCode;
    }

    public void setCommitUserCode(String commitUserCode) {
        this.commitUserCode = commitUserCode;
    }
    public Date getEffectiveDate() {
        return effectiveDate;
    }

    public void setEffectiveDate(Date effectiveDate) {
        this.effectiveDate = effectiveDate;
    }
    
}

==> ejc-techmanagement-impl-3.0.0-20230818.032505-44-sources.jar: com/ejianc/business/techmanagement/bean/NewTechConstructionPlanEntity.java <==
package com.ejianc.business.techmanagement.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 新技术应用施工方案实体
 * 
 * @author generator
 * 
 */
 @TableName("ejc_techmanagement_newtech_construction_plan")
public class NewTechConstructionPlanEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="create_user_name")
    private String createUserName; // 创建人名称
    @TableField(value="modify_user_name")
    private String modifyUserName; // 修改人名称
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="bill_name")
    private String billName; // 单据名称
    @TableField(value="content_overview")
    private String contentOverview; // 内容概述
    @TableField(value="validation_opinion")
    private String validationOpinion; // 项目部审定意见
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value = "bill_state")
    private Integer billState; //单据状态
    @TableField(value="commit_date")
    private Date commitDate; // 提交日期
    @TableField(value="commit_user_name")
    private String commitUserName; // 提交人名称
    @TableField(value="commit_user_code")
    private String commitUserCode; // 提交人账号
    @TableField(value="effective_date")
    private Date effectiveDate; // 生效日期

    @TableField(value = "project_id")
    private Long projectId; //项目Id
    @TableField(value = "project_name")
    private String projectName; //项目名称
    @TableField(value = "project_code")
    private String projectCode; //项目编码

    @TableField(value = "org_id")
    private Long orgId; //项目部Id
    @TableField(value = "org_name")
    private String orgName; //项目部名称
    @TableField(value = "org_code")
    private String orgCode; //项目部编码

    @TableField(value = "parent_org_id")
    private Long parentOrgId; //项目部上级组织Id

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }

    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }

    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }

    @TableField(value = "parent_org_name")
    private String parentOrgName; //项目部上级组织名称
    @TableField(value = "parent_org_code")
    private String parentOrgCode; //项目部上级组织编码

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public String getModifyUserName() {
        return modifyUserName;
    }

    public void setModifyUserName(String modifyUserName) {
        this.modifyUserName = modifyUserName;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public String getBillName() {
        return billName;
    }

    public void setBillName(String billName) {
        this.billName = billName;
    }
    public String getContentOverview() {
        return contentOverview;
    }

    public void setContentOverview(String contentOverview) {
        this.contentOverview = contentOverview;
    }
    public String getValidationOpinion() {
        return validationOpinion;
    }

    public void setValidationOpinion(String validationOpinion) {
        this.validationOpinion = validationOpinion;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Date getCommitDate() {
        return commitDate;
    }

    public void setCommitDate(Date commitDate) {
        this.commitDate = commitDate;
    }
    public String getCommitUserName() {
        return commitUserName;
    }

    public void setCommitUserName(String commitUserName) {
        this.commitUserName = commitUserName;
    }
    public String getCommitUserCode() {
        return commitUserCode;
    }

    public void setCommitUserCode(String commitUserCode) {
        this.commitUserCode = commitUserCode;
    }
    public Date getEffectiveDate() {
        return effectiveDate;
    }

    public void setEffectiveDate(Date effectiveDate) {
        this.effectiveDate = effectiveDate;
    }
    
}
